@@ -21,14 +21,18 @@ describe 'swift::storage::all' do
       :container_port => '6001',
       :account_port => '6002',
       :log_facility => 'LOG_LOCAL2',
-      :incoming_chmod => '0644',
-      :outgoing_chmod => '0644',
+      :incoming_chmod => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+      :outgoing_chmod => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
       :log_requests => true
     }
   end
 
   describe 'when an internal network ip is not specified' do
-    it_raises 'a Puppet::Error', /Must pass storage_local_net_ip/
+    if Puppet::Util::Package.versioncmp(Puppet.version, '4.3.0') >= 0
+      it_raises 'a Puppet::Error', /expects a value for parameter 'storage_local_net_ip'/
+    else
+      it_raises 'a Puppet::Error', /Must pass storage_local_net_ip/
+    end
   end
 
   [{  :storage_local_net_ip => '127.0.0.1' },
@@ -43,8 +47,8 @@ describe 'swift::storage::all' do
       :account_pipeline => ["5", "6"],
       :allow_versions => true,
       :log_facility => ['LOG_LOCAL2', 'LOG_LOCAL3'],
-      :incoming_chmod => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
-      :outgoing_chmod => 'Du=rwx,g=rx,o=rx,Fu=rw,g=r,o=r',
+      :incoming_chmod => '0644',
+      :outgoing_chmod => '0644',
       :log_requests => false
     }
   ].each do |param_set|
